@@ -10,7 +10,7 @@ class Test(TestCase):
         product = Product('uuid_1', 'product_1', "No image", "test")
         product_string = json_encode(product)
         expected_string = '{"_type": "product", "uuid": "uuid_1", "name": "product_1", ' \
-                          '"image": "No image", "category": "test", "task_uuid": "", "tags": [], "description": ""}'
+                          '"image": "No image", "category": "test", "process_uuid": "", "tags": [], "description": ""}'
 
         assert type(product_string) == str
         assert product_string == expected_string, f"Expected {expected_string}, got: {product_string}"
